/*
Chicken Coop menu Structure
 
 */

// Menu texts
PROGMEM const char top_menu_item00[]="Run Controller";
PROGMEM const char top_menu_item01[]="Set Time/Date";
PROGMEM const char top_menu_item02[]="Set Door Time";
PROGMEM const char top_menu_item03[]="Door Up";
PROGMEM const char top_menu_item04[]="Door Down";
PROGMEM const char top_menu_item05[]="Door Parameters";
PROGMEM const char top_menu_item06[]="About";
PGM_P const top_menu_items[] PROGMEM = {
  top_menu_item00, top_menu_item01, top_menu_item02, top_menu_item03, top_menu_item04, top_menu_item05, top_menu_item06};

PROGMEM const char sub_menu_1_item00[]="Set Open Rate";
PROGMEM const char sub_menu_1_item01[]="Set Close Rate";
PROGMEM const char sub_menu_1_item02[]="LCD Backlight";
PROGMEM const char sub_menu_1_item03[]="Back to main menu";
PGM_P const sub_menu_1_items[] PROGMEM = {
  sub_menu_1_item00, sub_menu_1_item01, sub_menu_1_item02, sub_menu_1_item03};


//This program is the main menu. It handles inputs from the keys, updates the menu or executes a certain menu function accordingly.
int global_style=105; // This is the style of the menu


void top_menu()
{
  int menu_pointer_1=0; // This stores the menu choice the user made.
  phi_prompt_struct myMenu; // This structure stores the main menu.

  // Initialize the top menu
  myMenu.ptr.list=(char**)&top_menu_items; // Assign the list to the pointer
  myMenu.low.i=0; // Default item highlighted on the list
  myMenu.high.i=6; // Last item of the list is size of the list - 1.
  myMenu.width=lcd_columns-((global_style&phi_prompt_arrow_dot)!=0)-((global_style&phi_prompt_scroll_bar)!=0); // Auto fit the size of the list to the screen. Length in characters of the longest list item.
  myMenu.step.c_arr[0]=lcd_rows-1; // rows to auto fit entire screen
  myMenu.step.c_arr[1]=1; // one col list
  myMenu.step.c_arr[2]=0; // y for additional feature such as an index
  myMenu.step.c_arr[3]=lcd_columns-4-((global_style&phi_prompt_index_list)!=0); // x for additional feature such as an index
  myMenu.col=0; // Display menu at column 0
  myMenu.row=1; // Display menu at row 1
  myMenu.option=global_style; // Option 0, display classic list, option 1, display 2X2 list, option 2, display list with index, option 3, display list with index2.

  digitalWrite(backLight, HIGH);
  run_controller();

  while(1) // This loops every time a menu item is selected.
  {
    lcd.clear();  // Refresh menu if a button has been pushed
    digitalWrite(backLight, HIGH);
    center_text("Coop Cont'r Menu");

    myMenu.option=global_style; // This makes sure the change of menu style is updated if there is a menu style option in this level of menu.
    myMenu.width=lcd_columns-((global_style&phi_prompt_arrow_dot)!=0)-((global_style&phi_prompt_scroll_bar)!=0); // This makes sure the change of menu style is updated if there is a menu style option in this level of menu. Auto fit the size of the list to the screen. Length in characters of the longest list item.
    myMenu.step.c_arr[3]=lcd_columns-4-((global_style&phi_prompt_index_list)!=0); // This makes sure the change of menu style is updated if there is a menu style option in this level of menu. x for additional feature such as an index
    select_list(&myMenu); // Use the select_list to ask the user to select an item of the list, that is a menu item from your menu.
    menu_pointer_1=myMenu.low.i; // Get the selected item number and store it in the menu pointer.
    switch (menu_pointer_1) // See which menu item is selected and execute that correspond function
    {
    case 0:
      SetFlashOn = false;
      run_controller();
      break;

    case 1:
      set_time_date();
      break;

    case 2:
      set_door_time();
      break;

    case 3:
      set_door_up();
      break;

    case 4:
      set_door_down();
      break;

    case 5:
      door_parameters();
      break;

    case 6:
      show_credit();
      break;

    default:
      break;
    }
  }
}


void set_door_up()
{
  RTC.get(rtc,true);
  MotorOnTime = rtc[0];
  door_change(DoorUp);

  while (stateMotor != STOP)
  {
    RTC.get(rtc,true);

    if (rtc[0]>=(MotorOnTime+MotorFailSafe))
    door_change(Overide);
    
    else
    door_change(0);
  }

}



void set_door_down()
{
  RTC.get(rtc,true);
  MotorOnTime = rtc[0];
  door_change(DoorDown);

  while (stateMotor != STOP)
  {
    RTC.get(rtc,true);

    if (rtc[0]>=(MotorOnTime+MotorFailSafe))
    door_change(Overide);
    
    else
    door_change(0);
  }

}


void door_parameters() // This is the sub_menu_1
{
  int menu_pointer_1=0;
  phi_prompt_struct myMenu; // This structure stores the sub menu.

  // Initialize the top menu
  myMenu.ptr.list=(char**)&sub_menu_1_items; // Assign the list to the pointer
  myMenu.low.i=0; // Default item highlighted on the list
  myMenu.high.i=3; // Last item of the list is size of the list - 1.
  myMenu.width=lcd_columns-((global_style&phi_prompt_arrow_dot)!=0)-((global_style&phi_prompt_scroll_bar)!=0); // Auto fit the size of the list to the screen. Length in characters of the longest list item.
  myMenu.step.c_arr[0]=lcd_rows-1; // rows to auto fit entire screen
  myMenu.step.c_arr[1]=1; // one col list
  myMenu.step.c_arr[2]=0; // y for additional feature such as an index
  myMenu.step.c_arr[3]=lcd_columns-4; // x for additional feature such as an index
  myMenu.col=0; // Display prompt at column 0
  myMenu.row=1; // Display prompt at row 1
  myMenu.option=global_style;

  while(1)
  {
    lcd.clear();  // Refresh menu if a button has been pushed
    center_text("Door Parameters");

    myMenu.option=global_style; // This makes sure the change of menu style is updated if there is a menu style option in this level of menu.
    myMenu.width=lcd_columns-((global_style&phi_prompt_arrow_dot)!=0)-((global_style&phi_prompt_scroll_bar)!=0); // Auto fit the size of the list to the screen. Length in characters of the longest list item.


    select_list(&myMenu);
    menu_pointer_1=myMenu.low.i;
    switch (menu_pointer_1)
    {
    case 0:
      sub_menu_OpenDoorRate();
      break;
    case 1:
      sub_menu_CloseDoorRate();
      break;

    case 2:
      sub_menu_BacklightTimer();
      break;

    case 3:
      return;
      break;

    default:
      break;
    }
  }
}


void sub_menu_OpenDoorRate()
{
  lcd.clear();
  lcd.print("Open Door Rate");

  int user_input=UpRate;
  phi_prompt_struct myIntegerInput;
  myIntegerInput.ptr.i_buffer=&user_input;
  myIntegerInput.low.i=0;
  myIntegerInput.high.i=500;
  myIntegerInput.step.i=20;
  myIntegerInput.col=10;
  myIntegerInput.row=2;
  myIntegerInput.width=3;
  myIntegerInput.option=1;
  input_integer(&myIntegerInput);
  UpRate=user_input;

}

void sub_menu_CloseDoorRate()
{
  lcd.clear();
  lcd.print("Close Door Rate");

  int user_input=DownRate;
  phi_prompt_struct myIntegerInput;
  myIntegerInput.ptr.i_buffer=&user_input;
  myIntegerInput.low.i=0;
  myIntegerInput.high.i=500;
  myIntegerInput.step.i=20;
  myIntegerInput.col=11;
  myIntegerInput.row=2;
  myIntegerInput.width=3;
  myIntegerInput.option=1;
  input_integer(&myIntegerInput);
  DownRate=user_input;

}

void sub_menu_BacklightTimer()
{
  lcd.clear();
  lcd.print("Backlight Time");

  int user_input=backLightTime;
  phi_prompt_struct myIntegerInput;
  myIntegerInput.ptr.i_buffer=&user_input;
  myIntegerInput.low.i=0;
  myIntegerInput.high.i=300;
  myIntegerInput.step.i=1;
  myIntegerInput.col=10;
  myIntegerInput.row=2;
  myIntegerInput.width=3;
  myIntegerInput.option=1;
  input_integer(&myIntegerInput);
  backLightTime=user_input;
}






